@@ -66,7 +66,8 @@ on exit if called).  This case is called MS_LIFE_FOREVER.
 The CLOSE_CONNECTION=ALWAYS setting provides to suppress the connection pooling
 for a particular layer. In this case the MS_LIFE_SINGLE setting is used, which
 ensures that a new connection is created for each request and it is always
-closed when the connection is released. This kind of connection cannot be reused.
+closed when the connection is released. This kind of connection cannot be
+reused.
 
 The callback is a function provided with the connection handle when it is
 registered.  It takes a single "void *" argument which is the connection
@@ -134,29 +135,27 @@ o The connection pooling API will let a connection be used/referenced multiple
 #include "mapserver.h"
 #include "mapthread.h"
 
-
-
 /* defines for lifetime.
    A positive number is a time-from-last use in seconds */
 
-#define MS_LIFE_FOREVER       -1
-#define MS_LIFE_ZEROREF       -2
-#define MS_LIFE_SINGLE        -3
+#define MS_LIFE_FOREVER -1
+#define MS_LIFE_ZEROREF -2
+#define MS_LIFE_SINGLE -3
 
 typedef struct {
   enum MS_CONNECTION_TYPE connectiontype;
   char *connection;
 
-  int   lifespan;
-  int   ref_count;
-  void*   thread_id;
-  int   debug;
+  int lifespan;
+  int ref_count;
+  void *thread_id;
+  int debug;
 
   time_t last_used;
 
-  void  *conn_handle;
+  void *conn_handle;
 
-  void  (*close)( void * );
+  void (*close)(void *);
 } connectionObj;
 
 /*
@@ -173,35 +172,30 @@ static connectionObj *connections = NULL;
 /*      Register a new connection with the connection pool tracker.     */
 /************************************************************************/
 
-void msConnPoolRegister( layerObj *layer,
-                         void *conn_handle,
-                         void (*close_func)( void * ) )
+void msConnPoolRegister(layerObj *layer, void *conn_handle,
+                        void (*close_func)(void *))
 
 {
   const char *close_connection = NULL;
   connectionObj *conn = NULL;
 
-  if( layer->debug )
-    msDebug( "msConnPoolRegister(%s,%s,%p)\n",
-             layer->name, layer->connection, conn_handle );
+  if (layer->debug)
+    msDebug("msConnPoolRegister(%s,%s,%p)\n", layer->name, layer->connection,
+            conn_handle);
 
   /* -------------------------------------------------------------------- */
   /*      We can't meaningful keep a connection with no connection or     */
   /*      connection type string on the layer.                            */
   /* -------------------------------------------------------------------- */
-  if( layer->connection == NULL ) {
-    if( layer->tileindex != NULL
-        && layer->connectiontype == MS_OGR ) {
+  if (layer->connection == NULL) {
+    if (layer->tileindex != NULL && layer->connectiontype == MS_OGR) {
       /* this is ok, no need to make a fuss */
     } else {
-      msDebug( "%s: Missing CONNECTION on layer %s.\n",
-               "msConnPoolRegister()",
-               layer->name );
+      msDebug("%s: Missing CONNECTION on layer %s.\n", "msConnPoolRegister()",
+              layer->name);
 
-      msSetError( MS_MISCERR,
-                  "Missing CONNECTION on layer %s.",
-                  "msConnPoolRegister()",
-                  layer->name );
+      msSetError(MS_MISCERR, "Missing CONNECTION on layer %s.",
+                 "msConnPoolRegister()", layer->name);
     }
     return;
   }
@@ -209,16 +203,15 @@ void msConnPoolRegister( layerObj *layer,
   /* -------------------------------------------------------------------- */
   /*      Grow the array of connection information objects if needed.     */
   /* -------------------------------------------------------------------- */
-  msAcquireLock( TLOCK_POOL );
+  msAcquireLock(TLOCK_POOL);
 
-  if( connectionCount == connectionMax ) {
+  if (connectionCount == connectionMax) {
     connectionMax += 10;
-    connectionObj* newConnections = (connectionObj *)
-                  realloc(connections,
-                          sizeof(connectionObj) * connectionMax );
-    if( newConnections == NULL ) {
+    connectionObj *newConnections = (connectionObj *)realloc(
+        connections, sizeof(connectionObj) * connectionMax);
+    if (newConnections == NULL) {
       msSetError(MS_MEMERR, NULL, "msConnPoolRegister()");
-      msReleaseLock( TLOCK_POOL );
+      msReleaseLock(TLOCK_POOL);
       return;
     }
     connections = newConnections;
@@ -232,7 +225,7 @@ void msConnPoolRegister( layerObj *layer,
   connectionCount++;
 
   conn->connectiontype = layer->connectiontype;
-  conn->connection = msStrdup( layer->connection );
+  conn->connection = msStrdup(layer->connection);
   conn->close = close_func;
   conn->ref_count = 1;
   conn->thread_id = msGetThreadId();
@@ -243,30 +236,28 @@ void msConnPoolRegister( layerObj *layer,
   /* -------------------------------------------------------------------- */
   /*      Categorize the connection handling information.                 */
   /* -------------------------------------------------------------------- */
-  close_connection =
-    msLayerGetProcessingKey( layer, "CLOSE_CONNECTION" );
+  close_connection = msLayerGetProcessingKey(layer, "CLOSE_CONNECTION");
 
-  if( close_connection == NULL )
+  if (close_connection == NULL)
     close_connection = "NORMAL";
 
-  if( strcasecmp(close_connection,"NORMAL") == 0 )
+  if (strcasecmp(close_connection, "NORMAL") == 0)
     conn->lifespan = MS_LIFE_ZEROREF;
-  else if( strcasecmp(close_connection,"DEFER") == 0 )
+  else if (strcasecmp(close_connection, "DEFER") == 0)
     conn->lifespan = MS_LIFE_FOREVER;
-  else if( strcasecmp(close_connection,"ALWAYS") == 0 )
+  else if (strcasecmp(close_connection, "ALWAYS") == 0)
     conn->lifespan = MS_LIFE_SINGLE;
   else {
     msDebug("msConnPoolRegister(): "
             "Unrecognised CLOSE_CONNECTION value '%s'\n",
-            close_connection );
+            close_connection);
 
-    msSetError( MS_MISCERR, "Unrecognised CLOSE_CONNECTION value '%s'",
-                "msConnPoolRegister()",
-                close_connection );
+    msSetError(MS_MISCERR, "Unrecognised CLOSE_CONNECTION value '%s'",
+               "msConnPoolRegister()", close_connection);
     conn->lifespan = MS_LIFE_ZEROREF;
   }
 
-  msReleaseLock( TLOCK_POOL );
+  msReleaseLock(TLOCK_POOL);
 }
 
 /************************************************************************/
@@ -277,45 +268,40 @@ void msConnPoolRegister( layerObj *layer,
 /*      well.                                                           */
 /************************************************************************/
 
-static void msConnPoolClose( int conn_index )
+static void msConnPoolClose(int conn_index)
 
 {
   connectionObj *conn = connections + conn_index;
 
-  if( conn->ref_count > 0 ) {
-    if( conn->debug )
-      msDebug( "msConnPoolClose(): "
-               "Closing connection %s even though ref_count=%d.\n",
-               conn->connection, conn->ref_count );
+  if (conn->ref_count > 0) {
+    if (conn->debug)
+      msDebug("msConnPoolClose(): "
+              "Closing connection %s even though ref_count=%d.\n",
+              conn->connection, conn->ref_count);
 
-    msSetError( MS_MISCERR,
-                "Closing connection %s even though ref_count=%d.",
-                "msConnPoolClose()",
-                conn->connection,
-                conn->ref_count );
+    msSetError(MS_MISCERR, "Closing connection %s even though ref_count=%d.",
+               "msConnPoolClose()", conn->connection, conn->ref_count);
   }
 
-  if( conn->debug )
-    msDebug( "msConnPoolClose(%s,%p)\n",
-             conn->connection, conn->conn_handle );
+  if (conn->debug)
+    msDebug("msConnPoolClose(%s,%p)\n", conn->connection, conn->conn_handle);
 
-  if( conn->close != NULL )
-    conn->close( conn->conn_handle );
+  if (conn->close != NULL)
+    conn->close(conn->conn_handle);
 
   /* free malloced() stuff in this connection */
-  free( conn->connection );
+  free(conn->connection);
 
   connectionCount--;
-  if( connectionCount == 0 ) {
+  if (connectionCount == 0) {
     /* if there are no connections left we will "cleanup".  */
     connectionMax = 0;
-    free( connections );
+    free(connections);
     connections = NULL;
   } else {
     /* move the last connection in place of our now closed one */
-    memcpy( connections + conn_index,
-            connections + connectionCount,
-            sizeof(connectionObj) );
+    memcpy(connections + conn_index, connections + connectionCount,
+           sizeof(connectionObj));
   }
 }
 
@@ -328,48 +314,48 @@ static void msConnPoolClose( int conn_index )
 /*      return NULL.                                                    */
 /************************************************************************/
 
-void *msConnPoolRequest( layerObj *layer )
+void *msConnPoolRequest(layerObj *layer)
 
 {
-  int  i;
-  const char* close_connection;
+  int i;
+  const char *close_connection;
 
-  if( layer->connection == NULL )
+  if (layer->connection == NULL)
     return NULL;
 
   /* check if we must always create a new connection */
-  close_connection = msLayerGetProcessingKey( layer, "CLOSE_CONNECTION" );
-  if( close_connection && strcasecmp(close_connection,"ALWAYS") == 0 )
+  close_connection = msLayerGetProcessingKey(layer, "CLOSE_CONNECTION");
+  if (close_connection && strcasecmp(close_connection, "ALWAYS") == 0)
     return NULL;
 
-  msAcquireLock( TLOCK_POOL );
-  for( i = 0; i < connectionCount; i++ ) {
+  msAcquireLock(TLOCK_POOL);
+  for (i = 0; i < connectionCount; i++) {
     connectionObj *conn = connections + i;
 
-    if( layer->connectiontype == conn->connectiontype
-        && strcasecmp( layer->connection, conn->connection ) == 0
-        && (conn->ref_count == 0 || conn->thread_id == msGetThreadId())
-        && conn->lifespan != MS_LIFE_SINGLE) {
+    if (layer->connectiontype == conn->connectiontype &&
+        strcasecmp(layer->connection, conn->connection) == 0 &&
+        (conn->ref_count == 0 || conn->thread_id == msGetThreadId()) &&
+        conn->lifespan != MS_LIFE_SINGLE) {
       void *conn_handle = NULL;
 
       conn->ref_count++;
       conn->thread_id = msGetThreadId();
       conn->last_used = time(NULL);
 
-      if( layer->debug ) {
-        msDebug( "msConnPoolRequest(%s,%s) -> got %p\n",
-                 layer->name, layer->connection, conn->conn_handle );
+      if (layer->debug) {
+        msDebug("msConnPoolRequest(%s,%s) -> got %p\n", layer->name,
+                layer->connection, conn->conn_handle);
         conn->debug = layer->debug;
       }
 
       conn_handle = conn->conn_handle;
 
-      msReleaseLock( TLOCK_POOL );
+      msReleaseLock(TLOCK_POOL);
       return conn_handle;
     }
   }
 
-  msReleaseLock( TLOCK_POOL );
+  msReleaseLock(TLOCK_POOL);
 
   return NULL;
 }
@@ -383,49 +369,47 @@ void *msConnPoolRequest( layerObj *layer )
 /*      acquired the pool lock.                                         */
 /************************************************************************/
 
-void msConnPoolRelease( layerObj *layer, void *conn_handle )
+void msConnPoolRelease(layerObj *layer, void *conn_handle)
 
 {
-  int  i;
+  int i;
 
-  if( layer->debug )
-    msDebug( "msConnPoolRelease(%s,%s,%p)\n",
-             layer->name, layer->connection, conn_handle );
+  if (layer->debug)
+    msDebug("msConnPoolRelease(%s,%s,%p)\n", layer->name, layer->connection,
+            conn_handle);
 
-  if( layer->connection == NULL )
+  if (layer->connection == NULL)
     return;
 
-  msAcquireLock( TLOCK_POOL );
-  for( i = 0; i < connectionCount; i++ ) {
+  msAcquireLock(TLOCK_POOL);
+  for (i = 0; i < connectionCount; i++) {
     connectionObj *conn = connections + i;
 
-    if( layer->connectiontype == conn->connectiontype
-        && strcasecmp( layer->connection, conn->connection ) == 0
-        && conn->conn_handle == conn_handle ) {
+    if (layer->connectiontype == conn->connectiontype &&
+        strcasecmp(layer->connection, conn->connection) == 0 &&
+        conn->conn_handle == conn_handle) {
       conn->ref_count--;
       conn->last_used = time(NULL);
 
-      if( conn->ref_count == 0 )
+      if (conn->ref_count == 0)
         conn->thread_id = 0;
 
-      if( conn->ref_count == 0 && (conn->lifespan == MS_LIFE_ZEROREF || conn->lifespan == MS_LIFE_SINGLE) )
-        msConnPoolClose( i );
+      if (conn->ref_count == 0 && (conn->lifespan == MS_LIFE_ZEROREF ||
+                                   conn->lifespan == MS_LIFE_SINGLE))
+        msConnPoolClose(i);
 
-      msReleaseLock( TLOCK_POOL );
+      msReleaseLock(TLOCK_POOL);
       return;
     }
   }
 
-  msReleaseLock( TLOCK_POOL );
+  msReleaseLock(TLOCK_POOL);
 
-  msDebug( "%s: Unable to find handle for layer '%s'.\n",
-           "msConnPoolRelease()",
-           layer->name );
+  msDebug("%s: Unable to find handle for layer '%s'.\n", "msConnPoolRelease()",
+          layer->name);
 
-  msSetError( MS_MISCERR,
-              "Unable to find handle for layer '%s'.",
-              "msConnPoolRelease()",
-              layer->name );
+  msSetError(MS_MISCERR, "Unable to find handle for layer '%s'.",
+             "msConnPoolRelease()", layer->name);
 }
 
 /************************************************************************/
@@ -437,22 +421,22 @@ void msConnPoolRelease( layerObj *layer, void *conn_handle )
 void msConnPoolCloseUnreferenced()
 
 {
-  int  i;
+  int i;
 
   /* this really needs to be commented out before commiting.  */
   /* msDebug( "msConnPoolCloseUnreferenced()\n" ); */
 
-  msAcquireLock( TLOCK_POOL );
-  for( i = connectionCount - 1; i >= 0; i-- ) {
+  msAcquireLock(TLOCK_POOL);
+  for (i = connectionCount - 1; i >= 0; i--) {
     connectionObj *conn = connections + i;
 
-    if( conn->ref_count == 0 ) {
+    if (conn->ref_count == 0) {
       /* for now we don't assume the locks are re-entrant, so release */
       /* it so msConnPoolClose() can get it.  */
-      msConnPoolClose( i );
+      msConnPoolClose(i);
     }
   }
-  msReleaseLock( TLOCK_POOL );
+  msReleaseLock(TLOCK_POOL);
 }
 
 /************************************************************************/
@@ -468,8 +452,8 @@ void msConnPoolFinalCleanup()
   /* this really needs to be commented out before commiting.  */
   /* msDebug( "msConnPoolFinalCleanup()\n" ); */
 
-  msAcquireLock( TLOCK_POOL );
-  while( connectionCount > 0 )
-    msConnPoolClose( 0 );
-  msReleaseLock( TLOCK_POOL );
+  msAcquireLock(TLOCK_POOL);
+  while (connectionCount > 0)
+    msConnPoolClose(0);
+  msReleaseLock(TLOCK_POOL);
 }
