@@ -50,7 +50,6 @@
 #include <signal.h>
 #endif
 
-
 /************************************************************************/
 /*                      FastCGI cleanup functions.                      */
 /************************************************************************/
@@ -58,18 +57,14 @@
 static int finish_process = 0;
 
 #ifndef _WIN32
-static void msCleanupOnSignal( int nInData )
-{
+static void msCleanupOnSignal(int nInData) {
   (void)nInData;
   finish_process = 1;
 }
 #endif
 
 #ifdef _WIN32
-static void msCleanupOnExit( void )
-{
-  finish_process = 1;
-}
+static void msCleanupOnExit(void) { finish_process = 1; }
 #endif
 
 #ifdef USE_FASTCGI
@@ -80,10 +75,10 @@ static void msCleanupOnExit( void )
 /*      This is the default implementation via stdio.                   */
 /************************************************************************/
 
-static int msIO_fcgiRead( void *cbData, void *data, int byteCount )
+static int msIO_fcgiRead(void *cbData, void *data, int byteCount)
 
 {
-  return (int) FCGI_fread( data, 1, byteCount, (FCGI_FILE *) cbData );
+  return (int)FCGI_fread(data, 1, byteCount, (FCGI_FILE *)cbData);
 }
 
 /************************************************************************/
@@ -92,10 +87,10 @@ static int msIO_fcgiRead( void *cbData, void *data, int byteCount )
 /*      This is the default implementation via stdio.                   */
 /************************************************************************/
 
-static int msIO_fcgiWrite( void *cbData, void *data, int byteCount )
+static int msIO_fcgiWrite(void *cbData, void *data, int byteCount)
 
 {
-  return (int) FCGI_fwrite( data, 1, byteCount, (FCGI_FILE *) cbData );
+  return (int)FCGI_fwrite(data, 1, byteCount, (FCGI_FILE *)cbData);
 }
 
 /************************************************************************/
@@ -109,19 +104,19 @@ static int msIO_installFastCGIRedirect()
   stdin_ctx.label = "fcgi";
   stdin_ctx.write_channel = MS_FALSE;
   stdin_ctx.readWriteFunc = msIO_fcgiRead;
-  stdin_ctx.cbData = (void *) FCGI_stdin;
+  stdin_ctx.cbData = (void *)FCGI_stdin;
 
   stdout_ctx.label = "fcgi";
   stdout_ctx.write_channel = MS_TRUE;
   stdout_ctx.readWriteFunc = msIO_fcgiWrite;
-  stdout_ctx.cbData = (void *) FCGI_stdout;
+  stdout_ctx.cbData = (void *)FCGI_stdout;
 
   stderr_ctx.label = "fcgi";
   stderr_ctx.write_channel = MS_TRUE;
   stderr_ctx.readWriteFunc = msIO_fcgiWrite;
-  stderr_ctx.cbData = (void *) FCGI_stderr;
+  stderr_ctx.cbData = (void *)FCGI_stderr;
 
-  msIO_installHandlers( &stdin_ctx, &stdout_ctx, &stderr_ctx );
+  msIO_installHandlers(&stdin_ctx, &stdout_ctx, &stderr_ctx);
 
   return MS_TRUE;
 }
@@ -130,59 +125,65 @@ static int msIO_installFastCGIRedirect()
 /************************************************************************/
 /*                                main()                                */
 /************************************************************************/
-int main(int argc, char *argv[])
-{
+int main(int argc, char *argv[]) {
   int sendheaders = MS_TRUE;
   struct mstimeval execstarttime, execendtime;
   struct mstimeval requeststarttime, requestendtime;
-  mapservObj  *mapserv = NULL;
+  mapservObj *mapserv = NULL;
   configObj *config = NULL;
 
-  /* 
-  ** Process -v and -h command line arguments  first end exit. We want to avoid any error messages 
+  /*
+  ** Process -v and -h command line arguments  first end exit. We want to avoid
+  *any error messages
   ** associated with msLoadConfig() or msSetup().
   */
-  const char* config_filename = NULL;
+  const char *config_filename = NULL;
   const bool use_command_line_options = getenv("QUERY_STRING") == NULL;
   if (use_command_line_options) {
     /* WARNING:
      * Do not parse command line arguments (especially those that could have
-     * dangerous consequences if controlled through a web request), without checking
-     * that the QUERY_STRING environment variable is *not* set, because in a
-     * CGI context, command line arguments can be generated from the content
-     * of the QUERY_STRING, and thus cause a security problem.
-     * For ex, "http://example.com/mapserv.cgi?-conf+bar
-     * would result in "mapserv.cgi -conf bar" being invoked.
-     * See https://github.com/MapServer/MapServer/pull/6429#issuecomment-952533589
+     * dangerous consequences if controlled through a web request), without
+     * checking that the QUERY_STRING environment variable is *not* set, because
+     * in a CGI context, command line arguments can be generated from the
+     * content of the QUERY_STRING, and thus cause a security problem. For ex,
+     * "http://example.com/mapserv.cgi?-conf+bar would result in "mapserv.cgi
+     * -conf bar" being invoked. See
+     * https://github.com/MapServer/MapServer/pull/6429#issuecomment-952533589
      * and https://datatracker.ietf.org/doc/html/rfc3875#section-4.4
-    */
-    for( int iArg = 1; iArg < argc; iArg++ ) {
-      if( strcmp(argv[iArg],"-v") == 0 ) {
+     */
+    for (int iArg = 1; iArg < argc; iArg++) {
+      if (strcmp(argv[iArg], "-v") == 0) {
         printf("%s\n", msGetVersion());
         fflush(stdout);
         exit(0);
-      } else if (strcmp(argv[iArg], "-h") == 0 || strcmp(argv[iArg], "--help") == 0) {
-        printf("Usage: mapserv [--help] [-v] [-nh] [QUERY_STRING=value] [PATH_INFO=value]\n");
+      } else if (strcmp(argv[iArg], "-h") == 0 ||
+                 strcmp(argv[iArg], "--help") == 0) {
+        printf("Usage: mapserv [--help] [-v] [-nh] [QUERY_STRING=value] "
+               "[PATH_INFO=value]\n");
         printf("                [-conf filename]\n");
         printf("\n");
         printf("Options :\n");
         printf("  -h, --help              Display this help message.\n");
         printf("  -v                      Display version and exit.\n");
-        printf("  -nh                     Suppress HTTP headers in CGI mode.\n");
-        printf("  -conf filename          Filename of the MapServer configuration file.\n");
-        printf("  QUERY_STRING=value      Set the QUERY_STRING in GET request mode.\n");
-        printf("  PATH_INFO=value         Set the PATH_INFO for an API request.\n");
+        printf(
+            "  -nh                     Suppress HTTP headers in CGI mode.\n");
+        printf("  -conf filename          Filename of the MapServer "
+               "configuration file.\n");
+        printf("  QUERY_STRING=value      Set the QUERY_STRING in GET request "
+               "mode.\n");
+        printf("  PATH_INFO=value         Set the PATH_INFO for an API "
+               "request.\n");
         fflush(stdout);
         exit(0);
-      } else if( iArg < argc-1 && strcmp(argv[iArg], "-conf") == 0) {
-        config_filename = argv[iArg+1];
+      } else if (iArg < argc - 1 && strcmp(argv[iArg], "-conf") == 0) {
+        config_filename = argv[iArg + 1];
         ++iArg;
       }
     }
   }
 
   config = msLoadConfig(config_filename); // first thing
-  if(config == NULL) {
+  if (config == NULL) {
 #ifdef USE_FASTCGI
     msIO_installFastCGIRedirect(); // FastCGI setup for error handling here
     FCGI_Accept();
@@ -195,7 +196,7 @@ int main(int argc, char *argv[])
   /*      Initialize mapserver.  This sets up threads, GD and GEOS as     */
   /*      well as using MS_ERRORFILE and MS_DEBUGLEVEL env vars if set.   */
   /* -------------------------------------------------------------------- */
-  if( msSetup() != MS_SUCCESS ) {
+  if (msSetup() != MS_SUCCESS) {
 #ifdef USE_FASTCGI
     msIO_installFastCGIRedirect(); // FastCGI setup for error handling here
     FCGI_Accept();
@@ -206,7 +207,7 @@ int main(int argc, char *argv[])
     exit(0);
   }
 
-  if(msGetGlobalDebugLevel() >= MS_DEBUGLEVEL_TUNING)
+  if (msGetGlobalDebugLevel() >= MS_DEBUGLEVEL_TUNING)
     msGettimeofday(&execstarttime, NULL);
 
   /* -------------------------------------------------------------------- */
@@ -214,21 +215,22 @@ int main(int argc, char *argv[])
   /*      commandline switches, but we provide a few for test/debug       */
   /*      purposes.                                                       */
   /* -------------------------------------------------------------------- */
-  if(use_command_line_options) {
-    for( int iArg = 1; iArg < argc; iArg++ ) {
-      if(strcmp(argv[iArg], "-nh") == 0) {
+  if (use_command_line_options) {
+    for (int iArg = 1; iArg < argc; iArg++) {
+      if (strcmp(argv[iArg], "-nh") == 0) {
         sendheaders = MS_FALSE;
-        msIO_setHeaderEnabled( MS_FALSE );
-      } else if( strncmp(argv[iArg], "QUERY_STRING=", 13) == 0 ) {
+        msIO_setHeaderEnabled(MS_FALSE);
+      } else if (strncmp(argv[iArg], "QUERY_STRING=", 13) == 0) {
         /* Debugging hook... pass "QUERY_STRING=..." on the command-line */
-        putenv( "REQUEST_METHOD=GET" );
+        putenv("REQUEST_METHOD=GET");
         /* coverity[tainted_string] */
-        putenv( argv[iArg] );
-      } else if( strncmp(argv[iArg], "PATH_INFO=", 10) == 0 ) {
-        /* Debugging hook for APIs... pass "PATH_INFO=..." on the command-line */
-        putenv( "REQUEST_METHOD=GET" );
+        putenv(argv[iArg]);
+      } else if (strncmp(argv[iArg], "PATH_INFO=", 10) == 0) {
+        /* Debugging hook for APIs... pass "PATH_INFO=..." on the command-line
+         */
+        putenv("REQUEST_METHOD=GET");
         /* coverity[tainted_string] */
-        putenv( argv[iArg] );
+        putenv(argv[iArg]);
       }
     }
   }
@@ -237,8 +239,8 @@ int main(int argc, char *argv[])
   /*      Setup cleanup magic, mainly for FastCGI case.                   */
   /* -------------------------------------------------------------------- */
 #ifndef _WIN32
-  signal( SIGUSR1, msCleanupOnSignal );
-  signal( SIGTERM, msCleanupOnSignal );
+  signal(SIGUSR1, msCleanupOnSignal);
+  signal(SIGTERM, msCleanupOnSignal);
 #endif
 
 #ifdef USE_FASTCGI
@@ -246,55 +248,58 @@ int main(int argc, char *argv[])
 
   /* In FastCGI case we loop accepting multiple requests.  In normal CGI */
   /* use we only accept and process one request.  */
-  while( !finish_process && FCGI_Accept() >= 0 ) {
+  while (!finish_process && FCGI_Accept() >= 0) {
 #endif /* def USE_FASTCGI */
 
     /* -------------------------------------------------------------------- */
     /*      Process a request.                                              */
     /* -------------------------------------------------------------------- */
     mapserv = msAllocMapServObj();
-    mapserv->sendheaders = sendheaders; /* override the default if necessary (via command line -nh switch) */
+    mapserv->sendheaders = sendheaders; /* override the default if necessary
+                                           (via command line -nh switch) */
 
-    mapserv->request->NumParams = loadParams(mapserv->request, NULL, NULL, 0, NULL);
-    if(msCGIIsAPIRequest(mapserv) == MS_FALSE && mapserv->request->NumParams == -1) { /* no QUERY_STRING or PATH_INFO */
+    mapserv->request->NumParams =
+        loadParams(mapserv->request, NULL, NULL, 0, NULL);
+    if (msCGIIsAPIRequest(mapserv) == MS_FALSE &&
+        mapserv->request->NumParams == -1) { /* no QUERY_STRING or PATH_INFO */
       msCGIWriteError(mapserv);
       goto end_request;
     }
 
     mapserv->map = msCGILoadMap(mapserv, config);
-    if(!mapserv->map) {
+    if (!mapserv->map) {
       msCGIWriteError(mapserv);
       goto end_request;
     }
 
-    if( mapserv->map->debug >= MS_DEBUGLEVEL_TUNING)
+    if (mapserv->map->debug >= MS_DEBUGLEVEL_TUNING)
       msGettimeofday(&requeststarttime, NULL);
 
 #ifdef USE_FASTCGI
-    if( mapserv->map->debug ) {
+    if (mapserv->map->debug) {
       static int nRequestCounter = 1;
 
-      msDebug( "CGI Request %d on process %d\n", nRequestCounter, getpid() );
+      msDebug("CGI Request %d on process %d\n", nRequestCounter, getpid());
       nRequestCounter++;
     }
 #endif
 
-    if(mapserv->request->api_path != NULL) {
-      if(msCGIDispatchAPIRequest(mapserv) != MS_SUCCESS) {
-	msCGIWriteError(mapserv);
-	goto end_request;
+    if (mapserv->request->api_path != NULL) {
+      if (msCGIDispatchAPIRequest(mapserv) != MS_SUCCESS) {
+        msCGIWriteError(mapserv);
+        goto end_request;
       }
-    } else if(msCGIDispatchRequest(mapserv) != MS_SUCCESS) {
+    } else if (msCGIDispatchRequest(mapserv) != MS_SUCCESS) {
       msCGIWriteError(mapserv);
       goto end_request;
     }
 
-end_request:
-    if(mapserv->map && mapserv->map->debug >= MS_DEBUGLEVEL_TUNING) {
+  end_request:
+    if (mapserv->map && mapserv->map->debug >= MS_DEBUGLEVEL_TUNING) {
       msGettimeofday(&requestendtime, NULL);
       msDebug("mapserv request processing time (msLoadMap not incl.): %.3fs\n",
-              (requestendtime.tv_sec+requestendtime.tv_usec/1.0e6)-
-              (requeststarttime.tv_sec+requeststarttime.tv_usec/1.0e6) );
+              (requestendtime.tv_sec + requestendtime.tv_usec / 1.0e6) -
+                  (requeststarttime.tv_sec + requeststarttime.tv_usec / 1.0e6));
     }
     msFreeMapServObj(mapserv);
 #ifdef USE_FASTCGI
@@ -305,11 +310,11 @@ end_request:
 #endif
 
   /* normal case, processing is complete */
-  if(msGetGlobalDebugLevel() >= MS_DEBUGLEVEL_TUNING) {
+  if (msGetGlobalDebugLevel() >= MS_DEBUGLEVEL_TUNING) {
     msGettimeofday(&execendtime, NULL);
     msDebug("mapserv total execution time: %.3fs\n",
-            (execendtime.tv_sec+execendtime.tv_usec/1.0e6)-
-            (execstarttime.tv_sec+execstarttime.tv_usec/1.0e6) );
+            (execendtime.tv_sec + execendtime.tv_usec / 1.0e6) -
+                (execstarttime.tv_sec + execstarttime.tv_usec / 1.0e6));
   }
   msCleanup();
   msFreeConfig(config);
@@ -319,5 +324,5 @@ end_request:
   fflush(stdout);
 #endif
 
-  exit( 0 );
+  exit(0);
 }
